@@ -414,22 +414,50 @@ def after_success(dry_run: bool = True) -> None:
     if dry_run:
         return
 
-    command_prefix = get_env_data("cPREFIX")
-    cc_test_reporter_id = get_env_data("CC_TEST_REPORTER_ID").strip()
-
     if do_coverage():
-        run(description="coverage report", command=f"{command_prefix} coverage report")
+        coverage_report()
+        coverage_codecov()
+        coverage_codeclimate()
+    else:
+        lib_log_utils.banner_spam("coverage is disabled")
 
-        if do_upload_codecov():
-            if is_scheduled():
-                lib_log_utils.banner_spam("this is a scheduled build, therefore we dont upload codecov coverage AGAIN , because of codecov error 'Too many "
-                                          "uploads to this commit.'")
-            else:
-                run(description="coverage upload to codecov", command=f"{command_prefix} codecov")
+
+def coverage_report() -> None:
+    """ create coverage report """
+    command_prefix = get_env_data("cPREFIX")
+    run(description="coverage report", command=f"{command_prefix} coverage report")
+
+
+def coverage_codecov() -> None:
+    """ upload coverage to codecov, except on scheduled builds """
+    command_prefix = get_env_data("cPREFIX")
+    if do_upload_codecov():
+        if is_scheduled():
+            lib_log_utils.banner_spam("this is a scheduled build, therefore we dont upload codecov coverage AGAIN , because of codecov error 'Too many "
+                                      "uploads to this commit.'")
         else:
-            lib_log_utils.banner_spam("codecov upload disabled")
+            warn_if_no_codecov_token()
+            slug = get_env_data("GITHUB_REPOSITORY").strip()
+            run(description="coverage upload to codecov", command=f"{command_prefix} codecov --slug {slug}")
+    else:
+        lib_log_utils.banner_spam("codecov upload disabled")
 
-        if do_upload_code_climate() and cc_test_reporter_id:
+
+def warn_if_no_codecov_token() -> None:
+    slug = get_env_data("GITHUB_REPOSITORY").strip()
+    codecov_token = get_env_data("CODECOV_TOKEN").strip()
+    if not codecov_token:
+        lib_log_utils.banner_spam(f"please pass the Repository Secret CODECOV_TOKEN for {slug} under "
+                                  f"https://github.com/{slug}/settings/secrets/actions")
+
+
+def coverage_codeclimate() -> None:
+    """ upload coverage to codeclimate, except on scheduled builds """
+    cc_test_reporter_id = get_env_data("CC_TEST_REPORTER_ID").strip()
+    if do_upload_code_climate() and cc_test_reporter_id:
+        if is_scheduled():
+            lib_log_utils.banner_spam("this is a scheduled build, therefore we dont upload test results to codeclimate")
+        else:
             if is_ci_runner_os_macos() or is_ci_runner_os_linux():
                 download_code_climate_test_reporter_on_linux_or_macos()
                 upload_code_climate_test_report_on_linux_or_macos()
@@ -437,8 +465,8 @@ def after_success(dry_run: bool = True) -> None:
                 lib_log_utils.banner_warning('Code Climate: no working "codeclimate-test-reporter" for Windows available, Nov. 2021')
             else:
                 lib_log_utils.banner_warning("Code Climate Coverage - unknown RUNNER_OS ")
-        else:
-            lib_log_utils.banner_spam("Code Climate Coverage is disabled, no CC_TEST_REPORTER_ID")
+    else:
+        lib_log_utils.banner_spam("Code Climate Coverage is disabled, or missing CC_TEST_REPORTER_ID")
 
 
 def download_code_climate_test_reporter_on_linux_or_macos() -> None:
@@ -481,8 +509,8 @@ def deploy(dry_run: bool = True) -> None:
     ---------
     cPREFIX
         from environment, the command prefix like 'wine' or ''
-    PYPI_PASSWORD
-        from environment, passed as secure, encrypted variable to environment
+    PYPI_UPLOAD_API_TOKEN
+        from environment, passed as secure, encrypted variable via the GitHub repository secrets
     DEPLOY_SDIST, DEPLOY_WHEEL
         from environment, one of it needs to be true
     dry_run
@@ -499,9 +527,9 @@ def deploy(dry_run: bool = True) -> None:
 
     if dry_run:
         return
-    pypi_password = get_env_data("PYPI_PASSWORD").strip()
-    if not pypi_password:
-        lib_log_utils.banner_warning("can not deploy, because secret PYPI_PASSWORD is missing")
+    pypi_api_upload_token = get_env_data("PYPI_UPLOAD_API_TOKEN").strip()
+    if not pypi_api_upload_token:
+        lib_log_utils.banner_warning("can not deploy, because secret PYPI_UPLOAD_API_TOKEN is missing")
     elif do_deploy():
         if not dry_run:  # pragma: no cover
             run(
@@ -509,10 +537,8 @@ def deploy(dry_run: bool = True) -> None:
                 command=" ".join(
                     [
                         get_python_prefix(),
-                        "-m twine upload --repository-url https://upload.pypi.org/legacy/ -u",
-                        get_github_username(),
-                        "-p",
-                        pypi_password,
+                        "-m twine upload --repository-url https://upload.pypi.org/legacy/ -u __token__ -p",
+                        pypi_api_upload_token,
                         "--skip-existing",
                         "dist/*",
                     ]
@@ -1091,7 +1117,7 @@ def is_scheduled() -> bool:
     """
     Returns True, if this is a scheduled run
     """
-    return get_github_eventname() == "scheduled"
+    return get_github_eventname() == "schedule"
 
 
 def get_env_data(env_variable: str) -> str:
